@@ -3,11 +3,13 @@ from . import scrape
 from . import cv
 from . import nlp
 from . import line
+from . import chatbot
 
 __all__ = [
     'openapi',
     'scrape',
     'cv',
     'nlp',
-    'line'
+    'line',
+    'chatbot'
 ]
\ No newline at end of file
